@@ -380,6 +380,10 @@ enum diff_category
   /// top cv-qualifiers change.
   FN_PARM_TYPE_TOP_CV_CHANGE_CATEGORY = 1 << 12,
 
+  /// A diff node in this category is a function parameter type which
+  /// cv-qualifiers change.
+  FN_PARM_TYPE_CV_CHANGE_CATEGORY = 1 << 13,
+
   /// A special enumerator that is the logical 'or' all the
   /// enumerators above.
   ///
@@ -399,6 +403,7 @@ enum diff_category
   | REDUNDANT_CATEGORY
   | CLASS_DECL_ONLY_DEF_CHANGE_CATEGORY
   | FN_PARM_TYPE_TOP_CV_CHANGE_CATEGORY
+  | FN_PARM_TYPE_CV_CHANGE_CATEGORY
 }; // enum diff_category
 
 diff_category
@@ -957,7 +962,7 @@ public:
   /// some of its children nodes.
   ///
   /// This is to be implemented by all descendants of this type.
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const = 0;
 
   /// Pure interface to report the diff in a serialized form that is
@@ -1003,7 +1008,7 @@ protected:
 
 public:
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const = 0;
 
   virtual ~type_diff_base();
@@ -1024,7 +1029,7 @@ protected:
 
 public:
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const = 0;
 
   virtual ~decl_diff_base();
@@ -1071,7 +1076,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1127,7 +1132,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1184,7 +1189,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1244,7 +1249,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1304,7 +1309,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1365,7 +1370,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1438,7 +1443,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1549,7 +1554,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1619,7 +1624,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual const string&
@@ -1730,7 +1735,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1839,7 +1844,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1899,7 +1904,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -1974,7 +1979,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -2032,7 +2037,7 @@ compute_diff(const function_decl_sptr	first,
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -2083,7 +2088,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -2141,7 +2146,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -2193,7 +2198,7 @@ public:
   virtual bool
   has_changes() const;
 
-  virtual bool
+  virtual enum change_kind
   has_local_changes() const;
 
   virtual void
@@ -2652,6 +2657,9 @@ is_decl_diff(const diff* diff);
 const type_decl_diff*
 is_diff_of_basic_type(const diff* diff);
 
+const type_decl_diff*
+is_diff_of_basic_type(const diff* diff, bool);
+
 const class_or_union_diff*
 is_diff_of_class_or_union_type(const diff *d);
 
@@ -2679,6 +2687,9 @@ is_array_diff(const diff* diff);
 const function_type_diff*
 is_function_type_diff(const diff* diff);
 
+const function_type_diff*
+is_function_type_diff_with_local_changes(const diff* diff);
+
 const typedef_diff*
 is_typedef_diff(const diff *diff);
 
@@ -2694,9 +2705,14 @@ is_pointer_diff(const diff* diff);
 const reference_diff*
 is_reference_diff(const diff* diff);
 
+const qualified_type_diff*
+is_qualified_type_diff(const diff* diff);
 bool
 is_reference_or_pointer_diff(const diff* diff);
 
+bool
+is_reference_or_pointer_diff_to_non_basic_distinct_types(const diff* diff);
+
 const fn_parm_diff*
 is_fn_parm_diff(const diff* diff);
 
@@ -2715,6 +2731,20 @@ is_child_node_of_base_diff(const diff* diff);
 const corpus_diff*
 is_corpus_diff(const diff* diff);
 
+const diff*
+peel_typedef_diff(const diff* dif);
+
+const diff*
+peel_pointer_diff(const diff* dif);
+
+const diff*
+peel_reference_diff(const diff* dif);
+
+const diff*
+peel_qualified_diff(const diff* dif);
+
+const diff*
+peel_pointer_or_qualified_type(const diff*dif);
 }// end namespace comparison
 
 }// end namespace abigail
