@@ -407,6 +407,9 @@ is_anonymous_type(type_base*);
 bool
 is_anonymous_type(const type_base_sptr&);
 
+const type_decl*
+is_type_decl(const type_base*);
+
 type_decl_sptr
 is_type_decl(const type_base_sptr&);
 
@@ -583,9 +586,15 @@ set_member_is_static(const decl_base_sptr&, bool);
 bool
 is_data_member(const var_decl&);
 
+var_decl*
+is_data_member(const type_or_decl_base*);
+
 bool
 is_data_member(const var_decl*);
 
+var_decl_sptr
+is_data_member(const type_or_decl_base_sptr&);
+
 bool
 is_data_member(const var_decl_sptr);
 
@@ -595,12 +604,21 @@ is_data_member(const decl_base_sptr&);
 var_decl*
 is_data_member(const decl_base *);
 
+var_decl*
+is_data_member(const decl_base *);
+
 bool
 is_anonymous_data_member(const decl_base&);
 
+const var_decl*
+is_anonymous_data_member(const type_or_decl_base*);
+
 const var_decl*
 is_anonymous_data_member(const decl_base*);
 
+var_decl_sptr
+is_anonymous_data_member(const type_or_decl_base_sptr&);
+
 var_decl_sptr
 is_anonymous_data_member(const decl_base_sptr&);
 
@@ -768,6 +786,9 @@ peel_qualified_type(const type_base*);
 const type_base_sptr
 peel_qualified_type(const type_base_sptr&);
 
+type_base*
+peel_qualified_or_typedef_type(const type_base* type);
+
 type_base_sptr
 peel_typedef_pointer_or_reference_type(const type_base_sptr,
 				       bool peel_qualified_type = true);
@@ -1242,6 +1263,14 @@ hash_type_or_decl(const type_or_decl_base_sptr &);
 bool
 function_decl_is_less_than(const function_decl&f, const function_decl &s);
 
+bool
+types_have_similar_structure(const type_base_sptr& first,
+			     const type_base_sptr& second);
+
+bool
+types_have_similar_structure(const type_base* first,
+			     const type_base* second);
+
 } // end namespace ir
 
 using namespace abigail::ir;
