@@ -199,6 +199,8 @@ struct diff_context::priv
   bool					leaf_changes_only_;
   bool					forbid_visiting_a_node_twice_;
   bool					reset_visited_diffs_for_each_interface_;
+  bool					hex_values_;
+  bool					show_offsets_sizes_in_bits_;
   bool					show_relative_offset_changes_;
   bool					show_stats_only_;
   bool					show_soname_change_;
@@ -225,6 +227,8 @@ struct diff_context::priv
       leaf_changes_only_(),
       forbid_visiting_a_node_twice_(true),
       reset_visited_diffs_for_each_interface_(),
+      hex_values_(),
+      show_offsets_sizes_in_bits_(true),
       show_relative_offset_changes_(true),
       show_stats_only_(false),
       show_soname_change_(true),
@@ -1049,7 +1053,10 @@ struct corpus_diff::priv
   bool
   added_unrefed_var_sym_is_suppressed(const elf_symbol*) const;
 
-  void count_leaf_changes(size_t &, size_t&);
+  void count_leaf_changes(size_t &num_changes, size_t &num_filtered);
+
+  void count_leaf_type_changes(size_t &num_type_changes,
+			       size_t &num_type_changes_filtered);
 
   void
   apply_filters_and_compute_diff_stats(corpus_diff::diff_stats&);
@@ -1221,6 +1228,12 @@ struct corpus_diff::diff_stats::priv
   size_t		num_added_var_syms_filtered_out;
   size_t		num_leaf_changes;
   size_t		num_leaf_changes_filtered_out;
+  size_t		num_leaf_type_changes;
+  size_t		num_leaf_type_changes_filtered_out;
+  size_t		num_leaf_func_changes;
+  size_t		num_leaf_func_changes_filtered_out;
+  size_t		num_leaf_var_changes;
+  size_t		num_leaf_var_changes_filtered_out;
 
   priv(diff_context_sptr ctxt)
     : ctxt_(ctxt),
@@ -1244,7 +1257,15 @@ struct corpus_diff::diff_stats::priv
       num_var_syms_removed(),
       num_removed_var_syms_filtered_out(),
       num_var_syms_added(),
-      num_added_var_syms_filtered_out()
+      num_added_var_syms_filtered_out(),
+      num_leaf_changes(),
+      num_leaf_changes_filtered_out(),
+      num_leaf_type_changes(),
+      num_leaf_type_changes_filtered_out(),
+      num_leaf_func_changes(),
+      num_leaf_func_changes_filtered_out(),
+      num_leaf_var_changes(),
+      num_leaf_var_changes_filtered_out()
   {}
 
   diff_context_sptr
@@ -1302,6 +1323,10 @@ void
 sort_string_diff_sptr_map(const string_diff_sptr_map& map,
 			  diff_sptrs_type& sorted);
 
+void
+sort_string_diff_ptr_map(const string_diff_ptr_map& map,
+			 diff_ptrs_type& sorted);
+
 void
 sort_string_base_diff_sptr_map(const string_base_diff_sptr_map& map,
 			       base_diff_sptrs_type& sorted);
