@@ -418,24 +418,28 @@ default_reporter::report_local_reference_type_changes(const reference_diff& d,
   reference_type_def_sptr f = d.first_reference(), s = d.second_reference();
   assert(f && s);
 
+  string f_repr = f->get_pretty_representation(),
+    s_repr = s->get_pretty_representation();
 
   if (f->is_lvalue() != s->is_lvalue())
     {
-      string f_repr = f->get_pretty_representation(),
-	s_repr = s->get_pretty_representation();
-
       out << indent;
       if (f->is_lvalue())
 	out << "lvalue reference type '" << f_repr
 	    << " became an rvalue reference type: '"
 	    << s_repr
-	    << "'";
+	    << "'\n";
       else
 	out << "rvalue reference type '" << f_repr
 	    << " became an lvalue reference type: '"
 	    << s_repr
 	    << "'\n";
     }
+  else if (!types_have_similar_structure(f->get_pointed_to_type().get(),
+					 s->get_pointed_to_type().get()))
+    out << indent
+	<< "reference type changed from: '"
+	<< f_repr << "' to: '" << s_repr << "'\n";
 }
 
 /// Report a @ref reference_diff in a serialized form.
@@ -452,19 +456,25 @@ default_reporter::report(const reference_diff& d, ostream& out,
   if (!d.to_be_reported())
     return;
 
-  report_local_reference_type_changes(d, out, indent);
+  enum change_kind k = ir::NO_CHANGE_KIND;
+  equals(*d.first_reference(), *d.second_reference(), &k);
 
-  if (diff_sptr dif = d.underlying_type_diff())
-    {
-      RETURN_IF_BEING_REPORTED_OR_WAS_REPORTED_EARLIER2(dif, "referenced type");
+  if ((k & LOCAL_CHANGE_KIND) && !(k & SUBTYPE_CHANGE_KIND))
+    report_local_reference_type_changes(d, out, indent);
 
-      out << indent
-	  << "in referenced type '"
-	  << dif->first_subject()->get_pretty_representation() << "'";
-      report_loc_info(dif->second_subject(), *d.context(), out);
-      out << ":\n";
-      dif->report(out, indent + "  ");
-    }
+  if (k & SUBTYPE_CHANGE_KIND)
+    if (diff_sptr dif = d.underlying_type_diff())
+      {
+	RETURN_IF_BEING_REPORTED_OR_WAS_REPORTED_EARLIER2(dif,
+							  "referenced type");
+
+	out << indent
+	    << "in referenced type '"
+	    << dif->first_subject()->get_pretty_representation() << "'";
+	report_loc_info(dif->second_subject(), *d.context(), out);
+	out << ":\n";
+	dif->report(out, indent + "  ");
+      }
 }
 
 /// Emit a textual report about the a @ref fn_parm_diff instance.
@@ -1890,14 +1900,27 @@ default_reporter::report(const corpus_diff& d, ostream& out,
 		  << fn->get_pretty_representation() << "'";
 	      report_loc_info((*i)->second_function_decl(), *ctxt, out);
 	      out << " has some indirect sub-type changes:\n";
-	      if ((fn->get_symbol()->has_aliases()
+	      if (// The symbol of the function has aliases and the
+		  // function is not a cdtor (yeah because c++ cdtors
+		  // usually have several aliases).
+		  (fn->get_symbol()->has_aliases()
 		   && !(is_member_function(fn)
 			&& get_member_function_is_ctor(fn))
 		   && !(is_member_function(fn)
 			&& get_member_function_is_dtor(fn)))
-		  || (is_c_language(get_translation_unit(fn)->get_language())
-		      && fn->get_name() != fn->get_linkage_name()))
+		  || // We are in C and the name of the function is
+		     // different from the symbol name -- without
+		     // taking the possible symbol version into
+		     // account (this usually means the programmers
+		     // was playing tricks with symbol names and
+		     // versions).
+		  (is_c_language(get_translation_unit(fn)->get_language())
+		      && fn->get_name() != fn->get_symbol()->get_name()))
 		{
+		  // As the name of the symbol of the function doesn't
+		  // seem to be obvious here, make sure to tell the
+		  // user about the name of the (function) symbol she
+		  // is looking at here.
 		  int number_of_aliases =
 		    fn->get_symbol()->get_number_of_aliases();
 		  if (number_of_aliases == 0)
