@@ -1,6 +1,6 @@
 // -*- Mode: C++ -*-
 //
-// Copyright (C) 2013-2015 Red Hat, Inc.
+// Copyright (C) 2013-2018 Red Hat, Inc.
 //
 // This file is part of the GNU Application Binary Interface Generic
 // Analysis and Instrumentation Library (libabigail).  This library is
@@ -29,8 +29,10 @@
 #include <cstring>
 #include <iostream>
 #include <sstream>
+#include "abg-config.h"
 #include "abg-dwarf-reader.h"
 #include "abg-ir.h"
+#include "abg-tools-utils.h"
 
 using std::cout;
 using std::cerr;
@@ -39,12 +41,16 @@ using std::ostream;
 using std::ostringstream;
 using std::vector;
 
+using abigail::ir::environment;
+using abigail::ir::environment_sptr;
 using abigail::dwarf_reader::lookup_symbol_from_elf;
 using abigail::elf_symbol;
+using abigail::elf_symbol_sptr;
 
 struct options
 {
   bool	show_help;
+  bool	display_version;
   char* elf_path;
   char* symbol_name;
   bool	demangle;
@@ -52,6 +58,7 @@ struct options
 
   options()
     : show_help(false),
+      display_version(false),
       elf_path(0),
       symbol_name(0),
       demangle(false),
@@ -63,10 +70,11 @@ static void
 display_usage(const string& prog_name, ostream &out)
 {
   out << "usage: " << prog_name << " [options] <elf file> <symbol-name>\n"
-       << "where [options] can be:\n"
-       << "  --help  display this help string\n"
-       << "  --demangle demangle the symbols from the symbol table\n"
-       << "  --no-absolute-path do not show absolute paths in messages\n";
+      << "where [options] can be:\n"
+      << "  --help  display this help string\n"
+      << "  --version|-v  display program version information and exit\n"
+      << "  --demangle  demangle the symbols from the symbol table\n"
+      << "  --no-absolute-path  do not show absolute paths in messages\n";
 }
 
 static void
@@ -98,6 +106,12 @@ parse_command_line(int argc, char* argv[], options& opts)
 	  opts.show_help = true;
 	  return;
 	}
+      else if (!strcmp(argv[i], "--version")
+	       || !strcmp(argv[i], "-v"))
+	{
+	  opts.display_version = true;
+	  return;
+	}
       else if (!strcmp(argv[i], "--demangle"))
 	opts.demangle = true;
       else if (!strcmp(argv[i], "--no-absolute-path"))
@@ -118,12 +132,21 @@ main(int argc, char* argv[])
       display_usage(argv[0], cout);
       return 1;
     }
+
+  if (opts.display_version)
+    {
+      abigail::tools_utils::emit_prefix(argv[0], cout)
+	<< abigail::tools_utils::get_library_version_string();
+      return 0;
+    }
+
   assert(opts.elf_path != 0
 	 && opts.symbol_name != 0);
 
   string p = opts.elf_path, n = opts.symbol_name;
-  vector<elf_symbol> syms;
-  if (!lookup_symbol_from_elf(p, n, opts.demangle, syms))
+  environment_sptr env(new environment);
+  vector<elf_symbol_sptr> syms;
+  if (!lookup_symbol_from_elf(env.get(), p, n, opts.demangle, syms))
     {
       cout << "could not find symbol '"
 	   << opts.symbol_name
@@ -135,29 +158,29 @@ main(int argc, char* argv[])
       return 0;
     }
 
-  elf_symbol sym = syms[0];
+  elf_symbol_sptr sym = syms[0];
   cout << " found symbol '" << n << "'";
-  if (n != sym.get_name())
-    cout << " (" << sym.get_name() << ")";
-    cout << ", an instance of "
-	 << (elf_symbol::type) sym.get_type()
-	 << " of " << sym.get_binding();
-    if (syms.size() > 1 || !sym.get_version().is_empty())
-      {
-	cout << ", of version";
-	if (syms.size () > 1)
-	  cout << "s";
-	cout << " ";
-	for (vector<elf_symbol>::const_iterator i = syms.begin();
-	     i != syms.end();
-	     ++i)
-	  {
-	    if (i != syms.begin())
-	      cout << ", ";
-	    cout << "'" << i->get_version().str() << "'";
-	  }
-      }
-    cout << '\n';
+  if (n != sym->get_name())
+    cout << " (" << sym->get_name() << ")";
+  cout << ", an instance of "
+       << (elf_symbol::type) sym->get_type()
+       << " of " << sym->get_binding();
+  if (syms.size() > 1 || !sym->get_version().is_empty())
+    {
+      cout << ", of version";
+      if (syms.size () > 1)
+	cout << "s";
+      cout << " ";
+      for (vector<elf_symbol_sptr>::const_iterator i = syms.begin();
+	   i != syms.end();
+	   ++i)
+	{
+	  if (i != syms.begin())
+	    cout << ", ";
+	  cout << "'" << (*i)->get_version().str() << "'";
+	}
+    }
+  cout << '\n';
 
   return 0;
 }
